<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_Hant">
<context>
    <name>BookmarksWidget</name>
    <message>
        <location filename="../forms/bookmarkswidget.ui" line="32"/>
        <source>Filter:</source>
        <translation>過濾：</translation>
    </message>
</context>
<context>
    <name>FontDialog</name>
    <message>
        <location filename="../forms/fontdialog.ui" line="14"/>
        <location filename="../forms/fontdialog.ui" line="73"/>
        <source>Select Terminal Font</source>
        <translation>選擇終端機字型</translation>
    </message>
    <message>
        <location filename="../forms/fontdialog.ui" line="32"/>
        <source>Font:</source>
        <translation>字型：</translation>
    </message>
    <message>
        <location filename="../forms/fontdialog.ui" line="42"/>
        <source>Size:</source>
        <translation>大小：</translation>
    </message>
    <message>
        <location filename="../forms/fontdialog.ui" line="59"/>
        <source>Preview</source>
        <translation>預覽</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="90"/>
        <source>Bookmarks</source>
        <translation>書籤</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="190"/>
        <source>Press &quot;%1&quot; to see the terminal.</source>
        <translation>按下「%1」以顯示終端機。</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="239"/>
        <source>&amp;Next Tab</source>
        <translation>下個分頁(&amp;N)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="242"/>
        <source>&amp;Previous Tab</source>
        <translation>上個分頁(&amp;P)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="251"/>
        <source>Move Tab &amp;Left</source>
        <translation>將分頁往左移動(&amp;L)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="254"/>
        <source>Move Tab &amp;Right</source>
        <translation>將分頁往右移動(&amp;R)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="273"/>
        <source>Split Terminal &amp;Horizontally</source>
        <translation>水平分割終端機(&amp;H)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="276"/>
        <source>Split Terminal &amp;Vertically</source>
        <translation>垂直分割終端機(&amp;V)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="281"/>
        <source>&amp;Collapse Subterminal</source>
        <translation>合併分割的終端機(&amp;C)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="232"/>
        <source>&amp;Clear Active Terminal</source>
        <translation>清空目前的終端機(&amp;C)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="245"/>
        <source>&amp;Previous Tab in History</source>
        <translation>歷史記錄中上一個分頁(&amp;P)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="248"/>
        <source>&amp;Next Tab in History</source>
        <translation>歷史記錄中下一個分頁(&amp;N)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="259"/>
        <source>Tab</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="260"/>
        <source>Go to</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="284"/>
        <source>&amp;Top Subterminal</source>
        <translation>上方的分割終端機(&amp;T)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="287"/>
        <source>&amp;Bottom Subterminal</source>
        <translation>下方的分割終端機(&amp;B)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="290"/>
        <source>L&amp;eft Subterminal</source>
        <translation>左方的分割終端機(&amp;e)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="293"/>
        <source>R&amp;ight Subterminal</source>
        <translation>右方的分割終端機(&amp;i)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="300"/>
        <source>Copy &amp;Selection</source>
        <translation>複製選取區(&amp;S)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="303"/>
        <source>Paste Clip&amp;board</source>
        <translation>貼上剪貼簿內容(&amp;B)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="306"/>
        <source>Paste S&amp;election</source>
        <translation>貼上選取區內容(&amp;E)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="309"/>
        <source>Zoom &amp;in</source>
        <translation>放大(&amp;I)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="312"/>
        <source>Zoom &amp;out</source>
        <translation>縮小(&amp;O)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="315"/>
        <source>Zoom rese&amp;t</source>
        <translation>重設縮放等級(&amp;T)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="320"/>
        <source>&amp;Find...</source>
        <translation>搜尋(&amp;F)…</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="328"/>
        <source>&amp;Save Session</source>
        <translation>儲存會話(&amp;S)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="334"/>
        <source>&amp;Load Session</source>
        <translation>讀取會話(&amp;L)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="341"/>
        <source>&amp;Toggle Menu</source>
        <translation>顯示/隱藏功能表(&amp;T)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="346"/>
        <source>Rename session</source>
        <translation>重新命名會話</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="355"/>
        <source>&amp;New Tab</source>
        <translation>新增分頁(&amp;N)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="359"/>
        <source>New Tab From &amp;Preset</source>
        <translation>由預設的設定新增分頁(&amp;P)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="360"/>
        <source>1 &amp;Terminal</source>
        <translation>一個終端機(&amp;T)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="362"/>
        <source>2 &amp;Horizontal Terminals</source>
        <translation>兩個水平的終端機(&amp;H)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="364"/>
        <source>2 &amp;Vertical Terminals</source>
        <translation>兩個垂直的終端機(&amp;V)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="366"/>
        <source>4 Terminal&amp;s</source>
        <translation>四個終端機(&amp;s)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="372"/>
        <source>&amp;Close Tab</source>
        <translation>關閉分頁(&amp;C)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="375"/>
        <source>&amp;New Window</source>
        <translation>新視窗(&amp;N)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="380"/>
        <source>&amp;Preferences...</source>
        <translation>偏好設定(&amp;P)…</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="384"/>
        <source>&amp;Quit</source>
        <translation>離開(&amp;Q)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="390"/>
        <source>&amp;Hide Window Borders</source>
        <translation>隱藏視窗邊界(&amp;H)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="401"/>
        <source>&amp;Show Tab Bar</source>
        <translation>顯示分頁列(&amp;S)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="409"/>
        <source>Fullscreen</source>
        <translation>全螢幕顯示</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="415"/>
        <source>Toggle Bookmarks</source>
        <translation>切換書籤</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="423"/>
        <source>&amp;Bottom</source>
        <translation>下(&amp;B)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="424"/>
        <source>&amp;Top</source>
        <translation>上(&amp;T)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="425"/>
        <location filename="../mainwindow.cpp" line="461"/>
        <source>&amp;Right</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="426"/>
        <location filename="../mainwindow.cpp" line="462"/>
        <source>&amp;Left</source>
        <translation>左(&amp;L)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="444"/>
        <source>&amp;Tabs Layout</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="460"/>
        <source>&amp;None</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="478"/>
        <source>S&amp;crollbar Layout</source>
        <translation>捲軸位置(&amp;C)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="491"/>
        <source>&amp;BlockCursor</source>
        <translation>區塊游標(&amp;B)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="492"/>
        <source>&amp;UnderlineCursor</source>
        <translation>底線游標(&amp;U)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="493"/>
        <source>&amp;IBeamCursor</source>
        <translation>垂直線游標(&amp;I)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="510"/>
        <source>&amp;Keyboard Cursor Shape</source>
        <translation>游標形狀(&amp;K)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="599"/>
        <source>Exit QTerminal</source>
        <translation>離開QTerminal</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="601"/>
        <source>Do not ask again</source>
        <translation>不再詢問</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="609"/>
        <source>Are you sure you want to exit?</source>
        <translation>確定要離開嗎？</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="640"/>
        <source>A lightweight multiplatform terminal emulator</source>
        <translation>輕量且支援多種平台的終端機模擬器</translation>
    </message>
</context>
<context>
    <name>PropertiesDialog</name>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="14"/>
        <source>Terminal settings</source>
        <translation>終端機設定</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="31"/>
        <source>Appearance</source>
        <translation>外觀</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="39"/>
        <location filename="../forms/propertiesdialog.ui" line="555"/>
        <source>Behavior</source>
        <translation>行為</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="47"/>
        <source>Shortcuts</source>
        <translation>快速鍵</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="55"/>
        <source>Dropdown</source>
        <translation>下拉模式</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="63"/>
        <source>Bookmarks</source>
        <translation>書籤</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="258"/>
        <source>Hide tab bar with only one tab</source>
        <translation>只有一個分頁時隱藏分頁列</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="275"/>
        <source>Color scheme</source>
        <translation>配色方案</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="335"/>
        <source>Scrollbar position</source>
        <translation>捲軸位置</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="204"/>
        <source>Start with preset:</source>
        <translation>以預設啟動：</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="368"/>
        <source>Show a border around the current terminal</source>
        <translation>顯示現在終端機的邊界</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="345"/>
        <source>Terminal transparency</source>
        <translation>終端機透明度</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="358"/>
        <source>Application transparency</source>
        <translation>應用程式透明度</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="215"/>
        <source>None (single terminal)</source>
        <translation>無 (單個終端機)</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="220"/>
        <source>2 terminals horizontally</source>
        <translation>兩個水平分割的終端機</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="225"/>
        <source>2 terminals vertically</source>
        <translation>兩個垂直分割的終端機</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="230"/>
        <source>4 terminals</source>
        <translation>四個終端機</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="117"/>
        <location filename="../forms/propertiesdialog.ui" line="389"/>
        <source> %</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="148"/>
        <source>Font</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="184"/>
        <source>&amp;Change...</source>
        <translation>更改(&amp;C)...</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="418"/>
        <source>Tabs position</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="238"/>
        <source>Widget style</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="194"/>
        <source>Show the menu bar</source>
        <translation>顯示菜單列</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="299"/>
        <source>Cursor shape</source>
        <translation>光標形狀</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="428"/>
        <source>Change window title based on current terminal</source>
        <translation>根據現在的終端機改變視窗的標題</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="445"/>
        <source>Change window icon based on current terminal</source>
        <translation>根據現在的終端機改變視窗的圖示</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="382"/>
        <source>Enable bi-directional text support</source>
        <translation>啟動雙向文字支援</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="265"/>
        <source>Background image:</source>
        <translation>背景圖片：</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="290"/>
        <source>Select</source>
        <translation>選擇</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="452"/>
        <source>Show terminal size on resize</source>
        <translation>在改變大小時顯示終端機的尺寸</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="435"/>
        <source>Fixed tab width:</source>
        <translation>固定的分頁寬度：</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="375"/>
        <location filename="../forms/propertiesdialog.ui" line="408"/>
        <source>px</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="325"/>
        <source>Show close button on each tab</source>
        <translation>在每個分頁上顯示關閉按鈕</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="248"/>
        <source>Terminal margin</source>
        <translation>終端邊界</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="459"/>
        <source>Use box drawing characters contained in the font</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="466"/>
        <source>Accelerators are activated by Alt and can interfere with the terminal.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="469"/>
        <source>No menu bar accelerator</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="530"/>
        <source>Emulation</source>
        <translation>模擬</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="539"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Which behavior to emulate. Note that this does not have to match your operating system.&lt;/p&gt;&lt;p&gt;The &lt;span style=&quot; font-weight:600;&quot;&gt;default&lt;/span&gt; emulation is a fallback with a minimal featureset.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;要模擬哪個行為。注意，這不用對應到你的作業系統。&lt;/p&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;預設&lt;/span&gt;模擬是回到最少的功能。&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="561"/>
        <source>Action after paste</source>
        <translation>貼上後的動作</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="571"/>
        <source>Confirm multiline paste</source>
        <translation>確認多行貼上</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="578"/>
        <source>Trim trailing newlines in pasted text</source>
        <translation>刪除貼上文字後的換行字符</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="598"/>
        <source>Open new terminals in current working directory</source>
        <translation>在目前的目錄開啟新的終端機</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="605"/>
        <source>Save Size when closing</source>
        <translation>關閉時儲存大小</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="612"/>
        <source>Save Position when closing</source>
        <translation>關閉時儲存位置</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="619"/>
        <source>Ask for confirmation when closing</source>
        <translation>關閉時詢問</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="629"/>
        <source>Unlimited history</source>
        <translation>無限制歷史紀錄</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="636"/>
        <source>History size (in lines)</source>
        <translation>歷史紀錄大小(行)</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="643"/>
        <source>Default $TERM</source>
        <translation>預設 $TERM</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="681"/>
        <source>Start with this size:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="688"/>
        <location filename="../forms/propertiesdialog.ui" line="702"/>
        <source> px</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="709"/>
        <source>Get current size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="767"/>
        <source>Shortcut</source>
        <translation>捷徑</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="772"/>
        <source>Key</source>
        <translation>按鍵</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="784"/>
        <source>Show on start</source>
        <translation>開始時顯示</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="791"/>
        <source>Size</source>
        <translation>大小</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="802"/>
        <source>Height</source>
        <translation>高度</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="812"/>
        <location filename="../forms/propertiesdialog.ui" line="829"/>
        <source>%</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="819"/>
        <source>Width</source>
        <translation>寬度</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="843"/>
        <source>Shortcut:</source>
        <translation>捷徑：</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="875"/>
        <source>Edit bookmark file contents</source>
        <translation>編輯書籤內容</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="897"/>
        <source>Enable bookmarks</source>
        <translation>啟用書籤</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="906"/>
        <source>Bookmark file</source>
        <translation>書籤</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="919"/>
        <source>Find...</source>
        <translation>搜尋...</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="928"/>
        <source>You can specify your own bookmarks file location. It allows easy bookmark sharing with tools like OwnCloud or Dropbox.</source>
        <translation>你可以指定書籤位置。它可以讓你的書籤更容易地以OwnCloud或Dropbox共享。</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="145"/>
        <source>No scrollbar</source>
        <translation>無捲動條</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="145"/>
        <location filename="../propertiesdialog.cpp" line="151"/>
        <source>Left</source>
        <translation>左</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="145"/>
        <location filename="../propertiesdialog.cpp" line="151"/>
        <source>Right</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="151"/>
        <source>Top</source>
        <translation>上</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="151"/>
        <source>Bottom</source>
        <translation>下</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="162"/>
        <source>BlockCursor</source>
        <translation>區塊游標</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="162"/>
        <source>UnderlineCursor</source>
        <translation>底線游標</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="162"/>
        <source>IBeamCursor</source>
        <translation>垂直線游標</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="175"/>
        <source>No move</source>
        <translation>不移動</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="175"/>
        <source>Move start</source>
        <translation>移動到開始</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="175"/>
        <source>Move end</source>
        <translation>移動到最後</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="180"/>
        <location filename="../propertiesdialog.cpp" line="272"/>
        <source>System Default</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="360"/>
        <source>Choose a background image</source>
        <translation>選擇背景圖片</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="361"/>
        <source>Images (*.bmp *.png *.xpm *.jpg)</source>
        <translation>圖片 (*.bmp *.png *.xpm *.jpg)</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="426"/>
        <source>Open or create bookmarks file</source>
        <translation>開啟或新增書籤</translation>
    </message>
</context>
<context>
    <name>QMessageBox</name>
    <message>
        <location filename="../termwidget.cpp" line="238"/>
        <source>Show Details...</source>
        <translation>顯示詳細資訊...</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../bookmarkswidget.cpp" line="110"/>
        <source>Local Bookmarks</source>
        <translation>本地書籤</translation>
    </message>
    <message>
        <location filename="../bookmarkswidget.cpp" line="168"/>
        <source>Synchronized Bookmarks</source>
        <translation>同步的書籤</translation>
    </message>
</context>
<context>
    <name>TabWidget</name>
    <message>
        <location filename="../tabwidget.cpp" line="78"/>
        <location filename="../tabwidget.cpp" line="230"/>
        <source>Shell No. %1</source>
        <translation>Shell 編號 %1</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="198"/>
        <source>Tab name</source>
        <translation>分頁名稱</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="199"/>
        <source>New tab name:</source>
        <translation>新分頁名稱：</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="219"/>
        <source>Select new tab title color</source>
        <translation>選擇新的分頁標題顏色</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="240"/>
        <source>Close session</source>
        <translation>關閉會話</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="242"/>
        <source>Change title color</source>
        <translation>更改標題顏色</translation>
    </message>
</context>
<context>
    <name>TermWidgetHolder</name>
    <message>
        <location filename="../termwidgetholder.cpp" line="78"/>
        <source>Load Session</source>
        <translation>讀取會話</translation>
    </message>
    <message>
        <location filename="../termwidgetholder.cpp" line="79"/>
        <source>List of saved sessions:</source>
        <translation>已儲存會話的列表：</translation>
    </message>
</context>
<context>
    <name>TermWidgetImpl</name>
    <message>
        <location filename="../termwidget.cpp" line="230"/>
        <source>Paste multiline text</source>
        <translation>貼上多行文字</translation>
    </message>
    <message>
        <location filename="../termwidget.cpp" line="231"/>
        <source>Are you sure you want to paste this text?</source>
        <translation>你確定要貼上這個文字嗎？</translation>
    </message>
</context>
<context>
    <name>mainWindow</name>
    <message>
        <location filename="../forms/qterminal.ui" line="14"/>
        <source>MainWindow</source>
        <translation>主視窗</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="59"/>
        <source>&amp;File</source>
        <translation>檔案(&amp;F)</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="67"/>
        <source>&amp;Actions</source>
        <translation>動作(&amp;A)</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="72"/>
        <source>&amp;Help</source>
        <translation>幫助(&amp;H)</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="79"/>
        <source>&amp;View</source>
        <translation>檢視(&amp;V)</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="84"/>
        <source>&amp;Edit</source>
        <translation>編輯(&amp;E)</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="100"/>
        <source>&amp;About...</source>
        <translation>關於(&amp;A)...</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="105"/>
        <source>About &amp;Qt...</source>
        <translation>關於Qt(&amp;Q)...</translation>
    </message>
</context>
</TS>
